@@ -1,7 +1,7 @@
 
 use numpy::{IntoPyArray,
             PyReadonlyArrayDyn,
-            PyArray2, PyArray1};
+            PyArray3, PyArray2, PyArray1};
 use pyo3::{pymodule, types::PyModule, PyResult, Python};
 
 mod topology;
@@ -40,11 +40,11 @@ fn del_msh(_py: Python, m: &PyModule) -> PyResult<()> {
     #[pyfn(m)]
     pub fn load_wavefront_obj(
         py: Python,
-        fpath: String) -> (&PyArray2<f32>, &PyArray2<f32>,
-                           &PyArray1<usize>,
-                           &PyArray1<usize>, &PyArray1<usize>) {
+        path_file: String) -> (&PyArray2<f32>, &PyArray2<f32>,
+                               &PyArray1<usize>,
+                               &PyArray1<usize>, &PyArray1<usize>) {
         let mut obj = del_msh::io_obj::WavefrontObj::<f32>::new();
-        obj.load(fpath.as_str());
+        obj.load(path_file.as_str());
         (
             numpy::ndarray::Array2::from_shape_vec(
                 (obj.vtx2xyz.len()/3,3), obj.vtx2xyz).unwrap().into_pyarray(py),
@@ -56,5 +56,32 @@ fn del_msh(_py: Python, m: &PyModule) -> PyResult<()> {
         )
     }
 
+    #[pyfn(m)]
+    pub fn load_wavefront_obj_as_triangle_mesh(
+        py: Python,
+        path_file: String) -> (&PyArray2<usize>,
+                               &PyArray2<f32>) {
+        let (tri2vtx, vtx2xyz)
+            = del_msh::io_obj::load_tri_mesh(&path_file, Option::None);
+        (
+            numpy::ndarray::Array2::from_shape_vec(
+                (tri2vtx.len()/3,3), tri2vtx).unwrap().into_pyarray(py),
+            numpy::ndarray::Array2::from_shape_vec(
+                (vtx2xyz.len()/3,3), vtx2xyz).unwrap().into_pyarray(py)
+        )
+    }
+
+    #[pyfn(m)]
+    pub fn unidex_vertex_attribute_for_triangle_mesh<'a>(
+        py: Python<'a>,
+        tri2vtx: PyReadonlyArrayDyn<'a, usize>,
+        vtx2xyz: PyReadonlyArrayDyn<'a, f32>) -> &'a PyArray3<f32> {
+        let tri2xyz = del_msh::unindex::unidex_vertex_attribute_for_triangle_mesh(
+            &tri2vtx.as_slice().unwrap(),
+            &vtx2xyz.as_slice().unwrap());
+        numpy::ndarray::Array3::from_shape_vec(
+            (tri2xyz.len()/9,3,3), tri2xyz).unwrap().into_pyarray(py)
+    }
+
     Ok(())
 }
\ No newline at end of file
